
# Type: source version




URI: [biolink:source_version](https://w3id.org/biolink/vocab/source_version)


## Domain and Range

[SourceFile](SourceFile.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [SourceFile](SourceFile.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | pav:version |

